<?php
/**
* Class which communicates with the ajax 
*/
class Widget {
	public static function generateResponse($options, $html_options=false) {
		if(!$html_options) $html_options = $options;
		if($_REQUEST['ajax']) return Widget::generateAjaxResponse($options);
		else return Widget::generateHtmlResponse($html_options);
	}

	/**
	* Pass an array of different parameters.  Depending on the input, it will generate a dialog box or perform functions
	*
	* @param array $options Array of different parameters, accepts js, header, and html.
	*
	* @return string Returns the box dialog
	*/
	public static function generateAjaxResponse($options=array(),$return_options = false) {
	
		//deal with deprecated options
		if($options == 'reload') $options = array('reload_parent'=>true);
		if($options == 'close') $options = array('hide_alert'=>true,'hide_notice'=>true);
		
		if(!is_array($options)) $options = array();
		
		//fix load option to right format
		if($options['load']) {
			$load = array();
			foreach($options['load'] as $target=>$url) {
				$load[] = array(
					'target'=>$target,
					'url'=>$url
				);
			}
			$options['load'] = $load;
		}
		
		//close, shortcut for hide notice and hide alert
		if($options['close']) {
			$options['hide_alert'] = $options['hide_notice'] = true;
			unset($options['close']);
		}
		
		//force trigger into array
		if($options['trigger'] && !is_array($options['trigger'])) {
			$options['trigger'] = array($options['trigger']);
		}
		
		//format triggers
		if($options['trigger']) {
			$triggers = array();
			foreach($options['trigger'] as $key=>$value) {
				//value is trigger name
				if(is_numeric($key)) {
					$triggers[] = array(
						'trigger'=>$value,
						'parameters'=>array()
					);
				}
				//key is trigger name, value is array of parameters
				else {
					if(!is_array($value)) $value = array($value);
					$triggers[] = array(
						'trigger'=>$key,
						'parameters'=>$value
					);
				}
			}
			$options['trigger'] = $triggers;
		}
		
		//dialog box
		if($options['header'] || $options['html'] || $options['buttons']) {
			$options['dialog'] = true;
			
			$actions = array(
				'close'=>'close_dialog()',
				'submit'=>'submit_dialog()'
			);
			
			if(!$options['buttons']) $options['buttons'] = array();
			if(!$options['parameters']) $options['parameters'] = array();
			
			//change predefined short cut buttons to full javascript function
			$buttons = array();
			foreach($options['buttons'] as $display=>&$action) {
				if(isset($actions[$action])) $action = $actions[$action];
				$buttons[] = array('display'=>$display, 'action'=>$action);
			}
			unset($options['buttons']);
			
			if(!empty($buttons)) {
				$options['parameters']['buttons'] = $buttons;
			}
			
			$parameters = array();
			foreach($options['parameters'] as $name=>&$value) {
				$parameters[] = array(
					'name'=>$name,
					'value'=>$value
				);
			}
			$options['parameters'] = $parameters;
		}
		
		//error message
		if($options['error']) {
			$options = array_merge_recursive($options,Widget::generateAjaxResponse(array(
				'header'=>'Error',
				'html'=>$options['error'],
				'buttons'=>array(
					translate('close')=>'close'
				)
			),true));
			$options['error'] = true;
		}
		
		if($return_options) return $options;
		else {
			header("Content-type: application/json");
			return json_encode($options);
		}
	}
	
	public static function generateHtmlResponse($options='') {
		global $linkpref, $site_root, $no_last_page;
		
		if(is_array($options) && $options['alert']) $_SESSION['alert'] = $options['alert'];
		if(is_array($options) && $options['notice']) $_SESSION['notice'] = $options['notice'];
		
		
		
		//where to go if canceled
		$previous_page = (isset($_REQUEST['referrer']))? $_REQUEST['referrer'] : 'cms/';
		
		
		//on close/reload/load exit
		if(empty($options) || $options == "close" || $options == "reload" || $options['load'] || $options['reload']) {
			header("Location: ".$site_root.$previous_page);
			exit();
		}		
		
		//unknown non-array option
		elseif(!is_array($options)) return Widget::generateHtmlResponse(array('error'=>"An error has occurred."));

		
		//display error message
		if($options['error']) {
			return Widget::generateHtmlResponse(array(
				'header'=>'Error',
				'html'=>$options['error'],
				'buttons'=>array(
					translate('close')=>'close'
				)
			));
		}
		
		//load page
		if($options['load_page']) {
			header("Location: ".($site_root.$options['load_page']));
			exit();
		}
		
		//display html
		if($options['header'] || $options['html']) {
			//don't store this is last page
			$no_last_page = true;
		
			//add template
			ob_start();
			
			global $title;
			$title= $options['header'];
			
			global $js_files;
			$js_files = isset($options['scripts'])? $options['scripts'] : array();
			
			include_header('cms_header');
				
			$html = ob_get_contents();
			ob_end_clean();
			
			//add html code			
			$html .= $options['html'];

			//add space
			$html .= "<br />";
			
			//add buttons
			if(!$options['buttons']) $options['buttons'] = array();
			foreach($options['buttons'] as $display=>$action) {
				if($action=='close') $html .= "<input type='button' class='ui-state-default ui-button ui-corner-all' onClick='history.back();' value='$display' /> ";
				elseif($action == 'submit') $submit_button = $display;
			}

			//add javascript code
			$html .= "<script type='text/javascript'>";			
			$html .= $options['js'];
			if($submit_button) $html .= "$(\"form:first\",$(\"#content\")).append(\"<input type='submit' class='ui-state-default ui-button ui-corner-all' name='submit' value='$submit_button' /> \");";
			$html .= "</script>";
			
			//add footer
			ob_start();
			footer();
			$html .= ob_get_contents();
			ob_end_clean();
			
			return $html;
		}
		
		echo "Unknown response";
	}
}
?>